# Change Log

All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/).

## Unreleased

* Added Read the Docs automatic documenatiotn [#15](https://github.com/hbenedek/binoculars/pull/15)
* Added README.md [#13](https://github.com/hbenedek/binoculars/pull/13)
* Added `KMeans` [#12](https://github.com/hbenedek/binoculars/pull/12)
* Added CHANGELOG.md [#10](https://github.com/hbenedek/binoculars/pull/10)
* Added `LogisticRegression` [#5](https://github.com/hbenedek/binoculars/pull/5)
* Added Python and Rust CI [#6](https://github.com/hbenedek/binoculars/pull/6) [#4](https://github.com/hbenedek/binoculars/pull/4)
* Added `LinearRegression` [#2](https://github.com/hbenedek/binoculars/pull/2)
* Added Pipenv and dev packages [#1](https://github.com/hbenedek/binoculars/pull/1)
